@@ -9,7 +9,7 @@ from .account import Account
 from .user import User
 from .token import Token
 
-__version__ = "1.0.22"
+__version__ = "1.0.23"
 
 
 class FreedomClient(object):
@@ -34,31 +34,34 @@ class FreedomClient(object):
         )
         assert self.api is not None
 
-    def get_account(self, account_id, params=None):
+    def get_account(self, account_id, params=None, api_call_kwargs={}):
         """:obj:`Account`: Fetch an account by its account ID (Axxxxxxxxxxxx).
 
         Args:
             account_id (str): Account ID.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
         account_data = self.api.call(
             "GET",
             "/accounts/{}".format(account_id),
             params=params,
+            **api_call_kwargs,
         )
         if not account_data:
             return None
         return Account(account_data["account"], account_data, api=self.api)
 
-    def get_accounts(self, params=None):
+    def get_accounts(self, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Account`: Fetch a list of all accounts that are visible/accessible.
 
         Args:
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
-        result = self.api.call("GET", "/accounts", params=params)
+        result = self.api.call("GET", "/accounts", params=params, **api_call_kwargs)
         if not result:
             return []
         return [
@@ -66,26 +69,28 @@ class FreedomClient(object):
             for account_data in result
         ]
 
-    def get_users(self, params=None):
+    def get_users(self, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`User`: Fetch a list of all users that are visible/accessible.
 
         Args:
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
-        result = self.api.call("GET", "/users", params=params)
+        result = self.api.call("GET", "/users", params=params, **api_call_kwargs)
         if not result:
             return []
         return [User(user_data["user"], user_data, api=self.api) for user_data in result]
 
-    def get_tokens(self, params=None):
+    def get_tokens(self, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
 
         Args:
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
-        result = self.api.call("GET", "/accounts", params=params)
+        result = self.api.call("GET", "/accounts", params=params, **api_call_kwargs)
         return result
 
     def create_token(
@@ -97,13 +102,14 @@ class FreedomClient(object):
             create_secret=False,
             params=None,
             raw=True,
+            api_call_kwargs={},
             **kwargs
-        ):
+            ):
         """:obj:`dict`: Creates a token and returns it.
 
         Args:
-            description (str) Token description 
-            allowed_actions (dict): Allowed actions for the new token. 
+            description (str) Token description
+            allowed_actions (dict): Allowed actions for the new token.
             accounts (list or *): List of accounts ids on which this token will have access.
                 Use '*' if the token needs access to all accounts
             devices (list or *): List of devices ids on which this token will have access.
@@ -112,6 +118,7 @@ class FreedomClient(object):
             params (dict): Optional query parameters.
             raw (bool): If true, will return the raw response of the API.
                 Otherwise it will create a Token object and return it with the returned token id.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
             **kwargs (dict): All extra attributes for the new token.
         """
         body = {
@@ -125,20 +132,22 @@ class FreedomClient(object):
             if params is None:
                 params = {}
             params['create_secret'] = 'true'
-        result = self.api.call("POST", "/tokens", data=body, params=params)
+        result = self.api.call("POST", "/tokens", data=body, params=params, **api_call_kwargs)
         if raw:
             return result
         else:
             return Token(result['token'], api=self.api)
 
-    def delete_token(self, token_id, params=None):
+    def delete_token(self, token_id, params=None, api_call_kwargs={}):
         """Deletes a specified token.
 
         Args:
             token_id (str): The Token id
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
-        result = self.api.call("DELETE", "/tokens/{}".format(token_id), params=params)
+        result = self.api.call("DELETE", "/tokens/{}".format(token_id), params=params, **api_call_kwargs)
         return result
 
     def report_issue(
@@ -150,6 +159,7 @@ class FreedomClient(object):
             device=None,
             user=None,
             params=None,
+            api_call_kwargs={},
             **kwargs):
         """Reports an issue to the API
 
@@ -161,6 +171,7 @@ class FreedomClient(object):
             device (str): The device id if present.
             user (str): The user if present.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
             **kwargs (dict): All the extra arguments will be sent into the body.
         """
 
@@ -219,4 +230,4 @@ class FreedomClient(object):
         }
         data.update(kwargs)
 
-        self.api.call("PUT", "/issues", data=data, params=params)
+        self.api.call("PUT", "/issues", data=data, params=params, **api_call_kwargs)
