@@ -45,7 +45,15 @@ class Account(Entity):
 
         return devices[0]
 
-    def create_device(self, name="default", description="", device_type="", location="", platform="ros"):
+    def create_device(
+            self,
+            name="default",
+            description="",
+            device_type="",
+            location="",
+            platform="ros",
+            api_call_kwargs={},
+            ):
         """:obj:`Device`: Creates a new device.
 
         Args:
@@ -54,6 +62,7 @@ class Account(Entity):
             device_type (str): Device type.
             location (str): Device location.
             platform (str): Device platform.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
         response = self.api.call(
@@ -65,7 +74,8 @@ class Account(Entity):
                 "type": device_type,
                 "location": location,
                 "platform": platform,
-            }
+            },
+            **api_call_kwargs
         )
 
         if response and response.get("status") != "success":
@@ -73,18 +83,20 @@ class Account(Entity):
 
         return self.get_device(response.get("device"))
 
-    def get_device(self, device_id, params=None):
+    def get_device(self, device_id, params=None, api_call_kwargs={}):
         """:obj:`Device`: Fetch an device by its device ID (Dxxxxxxxxxxxx).
 
         Args:
             device_id (str): Device ID.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
         device_data = self.api.call(
             "GET",
             "/accounts/{}/devices/{}".format(self._id, device_id),
             params=params,
+            **api_call_kwargs
         )
         if not device_data:
             return None
@@ -92,7 +104,7 @@ class Account(Entity):
         device = Device(device_data["device"], device_data, api=self.api)
         return device
 
-    def get_devices(self, attributes=None, zones=None, include_subzones=None, params=None):
+    def get_devices(self, attributes=None, zones=None, include_subzones=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Device`: Fetch a list of all devices in the account.
 
         Args:
@@ -101,6 +113,7 @@ class Account(Entity):
             attributes (zones): Optional list of zones to filter.
             include_subzones (zones): Optional list of subzones to filter.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
         if params is None:
@@ -112,33 +125,36 @@ class Account(Entity):
         if include_subzones is not None:
             params["include_subzones"] = json.dumps(include_subzones)
 
-        result = self.api.call("GET", "/accounts/{}/devices".format(self._id), params=params)
+        result = self.api.call("GET", "/accounts/{}/devices".format(self._id), params=params, **api_call_kwargs)
         if not isinstance(result, list):
             raise ValueError("API returned incorrect type")
         return [Device(device_data["device"], device_data, api=self.api) for device_data in result]
 
-    def get_zones(self, params=None):
+    def get_zones(self, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Zone`: Fetch a list of all zones in the account.
 
         Args:
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         result = self.api.call(
             "GET",
             "/accounts/{}/zones".format(self._id),
             params=params,
+            **api_call_kwargs,
         )
         if not result:
             return []
         return [Zone(data['id'], data, api=self.api) for data in result]
 
-    def get_alert(self, alert_id, attributes=None, params=None):
+    def get_alert(self, alert_id, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`Alert`: Fetch an Alert by its ID
 
         Args:
             alert_id (str): Alert ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alert = get_alert(
             self.api,
@@ -147,15 +163,17 @@ class Account(Entity):
             attributes=attributes,
             params=params,
             account_name=self.name,
+            api_call_kwargs=api_call_kwargs,
         )
         return alert
 
-    def get_alerts(self, attributes=None, params=None):
+    def get_alerts(self, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the account, according to the used params
 
         Args:
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
             self.api,
@@ -163,16 +181,18 @@ class Account(Entity):
             attributes=attributes,
             params=params,
             account_name=self.name,
+            api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_zone_alerts(self, zone_id, attributes=None, params=None):
+    def get_zone_alerts(self, zone_id, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the zone, according to the used params
 
         Args:
             zone_id (str): Zone ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
             self.api,
@@ -181,16 +201,18 @@ class Account(Entity):
             attributes=attributes,
             params=params,
             account_name=self.name,
+            api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_device_alerts(self, device_id, attributes=None, params=None):
+    def get_device_alerts(self, device_id, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the device, according to the used params
 
         Args:
             device_id (str): Device ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
             self.api,
@@ -199,20 +221,38 @@ class Account(Entity):
             attributes=attributes,
             params=params,
             account_name=self.name,
+            api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_setting(self, setting_name):
+    def get_setting(self, setting_name, params=None, api_call_kwargs={}):
         """:obj:`Setting`: Finds a setting by its name.
 
         Args:
             setting_name (string): name of the setting. Has to be a root level entry
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
-        return self.api.call("GET", "/accounts/{}/settings/{}".format(self._id, setting_name))
+        return self.api.call(
+            "GET",
+            "/accounts/{}/settings/{}".format(self._id, setting_name),
+            params=params,
+            **api_call_kwargs
+        )
 
-    def get_settings(self):
-        """:obj:`dict`: Fetch a all settings in the account."""
-        return self.api.call("GET", "/accounts/{}/settings".format(self._id))
+    def get_settings(self, params=None, api_call_kwargs={}):
+        """:obj:`dict`: Fetch a all settings in the account.
+
+        Args:
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+        """
+        return self.api.call(
+            "GET",
+            "/accounts/{}/settings".format(self._id),
+            params=params,
+            **api_call_kwargs
+        )
 
     @property
     def email(self):
@@ -244,7 +284,7 @@ class Account(Entity):
         """
         return self._data.get("name")
 
-    def get_statistics_csv(self, utc_start=None, utc_end=None, params=None):
+    def get_statistics_csv(self, utc_start=None, utc_end=None, params=None, api_call_kwargs={}):
         """Gets all the statistics for an account in a CSV format.
 
         Args:
@@ -253,6 +293,7 @@ class Account(Entity):
             utc_end (float): Returns statistics until the specified timestamp (inclusive).
                 If null, returns the statistics until current hour.
             params (dict): Extra parameters that could be included in the request.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
 
         Returns:
             String object with the CSV content.
@@ -269,10 +310,11 @@ class Account(Entity):
             "/accounts/{}/statistics/csv".format(self._id),
             raw=True,
             params=params,
+            **api_call_kwargs
         )
         return data
 
-    def put_monitoring(self, service, data, instance=None, pid=None):
+    def put_monitoring(self, service, data, instance=None, pid=None, params=None, api_call_kwargs={}):
         """Puts monitoring data such as heartbeats to the API
 
         Args:
@@ -281,6 +323,8 @@ class Account(Entity):
                          create metrics later.
             instance (str)*: Optional. By default will use the computer's name.
             pid (str)*: Optional. By default will use the current pid.
+            params (dict): Extra parameters that could be included in the request.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
         body = {
@@ -293,4 +337,6 @@ class Account(Entity):
             'PUT',
             "/accounts/{}/monitoring".format(self._id),
             data=body,
+            params=params,
+            **api_call_kwargs
         )
