@@ -4,6 +4,7 @@ import os
 import requests
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
+from requests.exceptions import ConnectTimeout, ReadTimeout
 
 DEFAULT_URL = "https://api.freedomrobotics.ai"
 
@@ -28,12 +29,14 @@ def api_call(*args, **kwargs):
 class APIHandler(object):
 
     def __init__(self,
-            token=None,
-            secret=None,
-            url=DEFAULT_URL,
-            retry_config=None,
-            profiler=False,
-            profiler_min_duration=1):
+                 token=None,
+                 secret=None,
+                 url=DEFAULT_URL,
+                 retry_config=None,
+                 profiler=False,
+                 profiler_min_duration=1,
+                 global_timeout=30,
+                 ):
         """Class that perform all the requests to the API
 
         Args:
@@ -45,6 +48,8 @@ class APIHandler(object):
             profiler (bool): If enabled, will enable the profiler on all API requests.
             profiler_min_duration (float/int): If profiler is enabled, will add the min duration
                 for a profile results to be dumped on the API side.
+            global_timeout (float/int): Default timeout for all API requests. By default is 30, which
+                is the lambda timeout for the API.
         """
         self.token = token
         self.secret = secret
@@ -54,6 +59,7 @@ class APIHandler(object):
         self.retry_config = retry_config
         self.profiler = profiler
         self.profiler_min_duration = profiler_min_duration
+        self.global_timeout = global_timeout
 
     def get_session(self):
         session = requests.Session()
@@ -86,7 +92,7 @@ class APIHandler(object):
                 url = DEFAULT_URL
             response = cls.simple_call(
                 url,
-                "PUT", 
+                "PUT",
                 "/users/{}/login".format(username),
                 data={
                     "password": password
@@ -116,7 +122,10 @@ class APIHandler(object):
         instance = cls(url=url)
         return instance.call(no_auth=True, *args, **kwargs)
 
-    def call(self, method, path, data=None, params=None, no_auth=False, raw=False):
+    def call(self, method, path, data=None, params=None, no_auth=False, raw=False, timeout=None):
+        if method.upper() not in ['GET', 'PUT', 'POST', 'DELETE', 'OPTIONS']:
+            raise Exception("Invalid method ")
+
         if no_auth:
             auth_headers = {}
         else:
@@ -130,48 +139,38 @@ class APIHandler(object):
             params['profiler'] = 'enable'
             params['profiler_min_duration'] = self.profiler_min_duration
 
-        url = self.url.strip("/") + "/" + path.strip("/")
-        if method == "GET":
-            with self.get_session() as session:
-                r = session.get(
-                    url,
-                    headers=auth_headers,
-                    params=params
-                )
-        elif method == "POST":
-            with self.get_session() as session:
-                r = session.post(
-                    url,
-                    headers=auth_headers,
-                    params=params,
-                    json=data
-                )
-        elif method == "PUT":
-            with self.get_session() as session:
-                r = session.put(
-                    url,
-                    headers=auth_headers,
-                    params=params,
-                    json=data
-                )
-        elif method == "DELETE":
-            with self.get_session() as session:
-                r = session.delete(
-                    url,
-                    headers=auth_headers,
-                    params=params,
-                )
+        request_kwargs = dict(
+            headers=auth_headers,
+            params=params,
+        )
+        timeout = timeout if timeout is not None else self.global_timeout
+        if timeout is not None:
+            request_kwargs['timeout'] = timeout
 
-        if r.status_code >= 400:
-            raise APIError.from_response(r)
+        if method.upper() in ['PUT', 'POST']:
+            request_kwargs['json'] = data
+
+        url = self.url.strip("/") + "/" + path.strip("/")
+
+        with self.get_session() as session:
+            func = getattr(session, method.lower())
+            try:
+                response = func(url, **request_kwargs)
+            except (ConnectTimeout, ReadTimeout) as e:
+                raise RequestTimeoutError(e)
+
+        if response.status_code >= 400:
+            raise APIError.from_response(response)
 
         try:
             if raw:
-                return r.text
+                return response.text
             else:
-                return r.json()
+                return response.json()
         except ValueError:
-            raise ServerError("Error parsing API response to JSON: [%d] %s" % (r.status_code, r.text))
+            raise ServerError(
+                "Error parsing API response to JSON: [{}] {}".format(response.status_code, response.text)
+            )
 
 
 class APIError(Exception):
@@ -211,3 +210,13 @@ class NotFoundError(APIError):
 
 class ServerError(APIError):
     ERROR = "Server Error"
+
+
+class RequestTimeoutError(APIError):
+
+    def __init__(self, request_exception):
+        if isinstance(request_exception, ConnectTimeout):
+            msg = "Timeout when connecting to the API: {}".format(request_exception)
+        elif isinstance(request_exception, ReadTimeout):
+            msg = "Timeout when reading response from the API: {}".format(request_exception)
+        Exception.__init__(self, msg)
