@@ -40,10 +40,12 @@ class Device(Entity):
         """
         return self._data.get("compute_architecture")
 
-    def create_token(self, params=None):
+    def create_token(self, params=None, api_call_kwargs={}):
         """dict: Creates a token and returns the response.
+
         Args:
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         response = self.api.call(
             "POST",
@@ -147,10 +149,14 @@ class Device(Entity):
         """
         return self._data.get("mc.instrumentation.remote_ssh")
 
-    def enable_remote_ssh(self):
+    def enable_remote_ssh(self, params=None, api_call_kwargs={}):
         """Enables remote SSH on the device. Following this method,
         periodically .update() the device and check for updates in
         .mc_instrumentation_remote_ssh() for the connection information.
+
+        Args:
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         data = [
             {
@@ -168,12 +174,14 @@ class Device(Entity):
                 self._data.get("account"),
                 self._id
             ),
-            data=data
+            data=data,
+            params=params,
+            **api_call_kwargs
         )
 
         return response
 
-    def data(self, start=None, end=None, topics=None, direction="forward", **params):
+    def data(self, start=None, end=None, topics=None, direction="forward", api_call_kwargs={}, **params):
         """iter: Fetches data from the robot for a specified interval and returns an iterator
         to page through the data. Each next() call to the iterator will return 1 message, and
         data will be fetched from the server as necessary until the end has been reached.
@@ -183,6 +191,8 @@ class Device(Entity):
             end (float): UNIX time of the end of the desired data interval.
             topics (`list` of `str`): List of topics of interest (in most cases, ROS topics).
             direction (str): "forward" or "backward".
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+            **params (dict): Optional query parameters.
         """
         if start is not None:
             params["utc_start"] = to_unix_time(start)
@@ -201,7 +211,8 @@ class Device(Entity):
             result = self.api.call(
                 "GET",
                 "/accounts/{}/devices/{}/data/".format(self.account, self._id),
-                params=params
+                params=params,
+                **api_call_kwargs
             )
 
             # sort messages in case server returns messages in wrong order
@@ -238,13 +249,16 @@ class Device(Entity):
                     start
                 )
 
-    def data_last(self, topics=None):
+    def data_last(self, topics=None, params=None, api_call_kwargs={}):
         """Returns the last message published by the device, as long as it is within the past 1 minute.
 
         Args:
             topics (`list` of `str`): Topics of interest.
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
-        params = {}
+        if params is None:
+            params = {}
         params["one_message_per_topic"] = "true"
         params["utc_start"] = to_unix_time(time.time() - 60.0)
         params["utc_end"] = to_unix_time(time.time())
@@ -255,7 +269,8 @@ class Device(Entity):
         result = self.api.call(
             "GET",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
-            params=params
+            params=params,
+            **api_call_kwargs
         )
 
         if result is None or len(result) == 0:
@@ -267,12 +282,13 @@ class Device(Entity):
 
         return result[-1]
 
-    def get_alerts(self, attributes=None, params=None):
+    def get_alerts(self, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the device, according to the used params
 
         Args:
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
             self.api,
@@ -281,10 +297,11 @@ class Device(Entity):
             attributes=attributes,
             params=params,
             device_name=self.name,
+            api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_statistics(self, utc_start=None, utc_end=None, params=None):
+    def get_statistics(self, utc_start=None, utc_end=None, params=None, api_call_kwargs={}):
         """GET statistics endpoint abstraction.
 
         Args:
@@ -293,6 +310,7 @@ class Device(Entity):
             utc_end (float): Returns statistics until the specified timestamp (inclusive).
                        If null, returns the statistics until current hour.
             params (dict): Extra parameters that could be included in the request.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
 
         Returns:
             Dictionary with utc timestamp hourly rounded as keys, and the calculated statistics
@@ -311,11 +329,12 @@ class Device(Entity):
         result = self.api.call(
             "GET",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
-            params=params
+            params=params,
+            **api_call_kwargs
         )
         return result
 
-    def put_statistics(self, data, params=None):
+    def put_statistics(self, data, params=None, api_call_kwargs={}):
         """PUT statistics endpoint abstraction
 
         Args:
@@ -323,10 +342,12 @@ class Device(Entity):
             More info about the object format can be found on API docs:
             https://docs.freedomrobotics.ai/reference#rest-api
             params (dict): Extra parameters that could be included in the request.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         self.api.call(
             "PUT",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
             data=data,
             params=params,
+            **api_call_kwargs
         )
